@@ -23,11 +23,15 @@
  * MA 02111-1307, USA.
  */
  
-#include "base16.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <assert.h>
 #include <stdlib.h>
 
+#include "base16.h"
+
 void
 base16_decode_init(struct base16_decode_ctx *ctx)
 {
@@ -61,7 +65,6 @@ base16_decode_single(struct base16_decode_ctx *ctx,
   if (src >= 0x80)
     return -1;
 
-  /* FIXME: This code could use more clever choices of constants. */
   digit = hex_decode_table[src];
   switch (digit)
     {
