@@ -69,10 +69,6 @@
 #define YARROW_MAX_ENTROPY 0x100000
 
 /* Forward declarations */
-
-static void
-yarrow_fast_reseed(struct yarrow256_ctx *ctx);
-
 static void
 yarrow_gate(struct yarrow256_ctx *ctx);
 
@@ -88,9 +84,8 @@ yarrow256_init(struct yarrow256_ctx *ctx,
   
   ctx->seeded = 0;
 
-  /* Not strictly, necessary, but it makes it easier to see if the
+  /* Not strictly necessary, but it makes it easier to see if the
    * values are sane. */
-  memset(ctx->seed_file, 0, YARROW256_SEED_FILE_SIZE);
   memset(ctx->counter, 0, sizeof(ctx->counter));
   
   ctx->nsources = n;
@@ -109,14 +104,10 @@ yarrow256_seed(struct yarrow256_ctx *ctx,
 	       unsigned length,
 	       const uint8_t *seed_file)
 {
-  /* FIXME: Perhaps it's better to use assert ? */
-  if (!length)
-    return;
+  assert(length > 0);
 
   sha256_update(&ctx->pools[YARROW_FAST], length, seed_file);
-  yarrow_fast_reseed(ctx);
-
-  ctx->seeded = 1;
+  yarrow256_fast_reseed(ctx);
 }
 
 /* FIXME: Generalize so that it generates a few more blocks at a
@@ -126,14 +117,14 @@ yarrow_generate_block(struct yarrow256_ctx *ctx,
 		      uint8_t *block)
 {
   unsigned i;
-  
+
   aes_encrypt(&ctx->key, sizeof(ctx->counter), block, ctx->counter);
 
   /* Increment counter, treating it as a big-endian number. This is
    * machine independent, and follows appendix B of the NIST
    * specification of cipher modes of operation.
    *
-   * We could keep a representation of thy counter as 4 32-bit values,
+   * We could keep a representation of the counter as 4 32-bit values,
    * and write entire words (in big-endian byteorder) into the counter
    * block, whenever they change. */
   for (i = sizeof(ctx->counter); i--; )
@@ -173,14 +164,14 @@ yarrow_iterate(uint8_t *digest)
 /* NOTE: The SHA-256 digest size equals the AES key size, so we need
  * no "size adaptor". */
 
-static void
-yarrow_fast_reseed(struct yarrow256_ctx *ctx)
+void
+yarrow256_fast_reseed(struct yarrow256_ctx *ctx)
 {
   uint8_t digest[SHA256_DIGEST_SIZE];
   unsigned i;
   
 #if YARROW_DEBUG
-  fprintf(stderr, "yarrow_fast_reseed\n");
+  fprintf(stderr, "yarrow256_fast_reseed\n");
 #endif
   
   /* We feed two block of output using the current key into the pool
@@ -200,6 +191,7 @@ yarrow_fast_reseed(struct yarrow256_ctx *ctx)
   yarrow_iterate(digest);
 
   aes_set_encrypt_key(&ctx->key, sizeof(digest), digest);
+  ctx->seeded = 1;
 
   /* Derive new counter value */
   memset(ctx->counter, 0, sizeof(ctx->counter));
@@ -208,33 +200,25 @@ yarrow_fast_reseed(struct yarrow256_ctx *ctx)
   /* Reset estimates. */
   for (i = 0; i<ctx->nsources; i++)
     ctx->sources[i].estimate[YARROW_FAST] = 0;
-
-  /* New seed file. */
-  /* FIXME: Extract this into a function of its own. */
-  for (i = 0; i < sizeof(ctx->seed_file); i+= AES_BLOCK_SIZE)
-    yarrow_generate_block(ctx, ctx->seed_file + i);
-
-  yarrow_gate(ctx);
 }
 
-static void
-yarrow_slow_reseed(struct yarrow256_ctx *ctx)
+void
+yarrow256_slow_reseed(struct yarrow256_ctx *ctx)
 {
   uint8_t digest[SHA256_DIGEST_SIZE];
   unsigned i;
 
 #if YARROW_DEBUG
-  fprintf(stderr, "yarrow_slow_reseed\n");
+  fprintf(stderr, "yarrow256_slow_reseed\n");
 #endif
 
   /* Get digest of the slow pool*/
-  
   sha256_digest(&ctx->pools[YARROW_SLOW], sizeof(digest), digest);
 
   /* Feed it into the fast pool */
   sha256_update(&ctx->pools[YARROW_FAST], sizeof(digest), digest);
 
-  yarrow_fast_reseed(ctx);
+  yarrow256_fast_reseed(ctx);
   
   /* Reset estimates. */
   for (i = 0; i<ctx->nsources; i++)
@@ -278,9 +262,6 @@ yarrow256_update(struct yarrow256_ctx *ctx,
 	   && (entropy > YARROW_MULTIPLIER * length) )
 	entropy = YARROW_MULTIPLIER * length;
 
-      /* FIXME: Calling a more sophisticated estimater should be done
-       * here. */
-
       entropy += source->estimate[current];
       if (entropy > YARROW_MAX_ENTROPY)
 	entropy = YARROW_MAX_ENTROPY;
@@ -300,7 +281,7 @@ yarrow256_update(struct yarrow256_ctx *ctx,
 #endif
       if (source->estimate[YARROW_FAST] >= YARROW_FAST_THRESHOLD)
 	{
-	  yarrow_fast_reseed(ctx);
+	  yarrow256_fast_reseed(ctx);
 	  return 1;
 	}
       else
@@ -308,15 +289,9 @@ yarrow256_update(struct yarrow256_ctx *ctx,
 
     case YARROW_SLOW:
       {
-	/* FIXME: This is somewhat inefficient. It would be better to
-	 * either maintain the count, or do this loop only if the
-	 * current source just crossed the threshold. */
-        
         if (!yarrow256_needed_sources(ctx))
 	  {
-	    yarrow_slow_reseed(ctx);
-	    ctx->seeded = 1;
-
+	    yarrow256_slow_reseed(ctx);
 	    return 1;
 	  }
 	else
@@ -389,9 +364,3 @@ yarrow256_needed_sources(struct yarrow256_ctx *ctx)
   
   return (k < YARROW_SLOW_K) ? (YARROW_SLOW_K - k) : 0;
 }
-
-void
-yarrow256_force_reseed(struct yarrow256_ctx *ctx)
-{
-  yarrow_slow_reseed(ctx);
-}
